"""

CRT1 specification for Paraguay.

Some tables (agriculture) differ from the template and
need an individual specification

Currently not all tables are included. Extend if you need all country
specific items in categories XXXXX

Tables included:

* **Energy:** 'Table1', 'Table1.A(a)s1', 'Table1.A(a)s2', 'Table1.A(a)s3',
  'Table1.A(a)s4', 'Table1.B.1', 'Table1.B.2', 'Table1.C',
* **Industrial processes:** 'Table2(I), 'Table2(II)',
* **Agriculture:** 'Table3', 'Table3.A', 'Table3.B(a)', 'Table3.B(b)', 'Table3.C', 'Table3.D',
* **LULUCF:**  'Table4',
* **Waste:**  'Table5',
* **Summary:** 'Summary1'

Missing tables are:

* **Energy:** 'Table1.A(b)', 'Table1.A(c)', 'Table1.A(d)', 'Table1.D'
* **Industrial processes:** 'Table2(I).A-H', 'Table2(II)B-Hs1', 'Table2(II)B-Hs2',
* **Agriculture:** 'Table3.E', 'Table3.F', 'Table3.G-I',
* **LULUCF**: All tables except Table4
* **Waste**:  'Table5.A', 'Table5.B', 'Table5.C', 'Table5.D'
* **Summary:** 'Summary2', 'Summary3', 'Flex_summary',
* **other:** 'Table6', 'Table7', 'Table8s1', 'Table8s2',
  'Table9', 'Table10s1', 'Table10s2', 'Table10s3', 'Table10s4', 'Table10s5',
  'Table10s6'



TODO:
 * Add missing tables
 * Add activity data

"""

from . import CRT1
from .util import unit_info

gwp_to_use = "AR5GWP100"

tables_identical = [  # some might have
    "Table1",
    "Table1.A(a)s1",
    "Table1.A(a)s2",
    "Table1.A(a)s3",
    "Table1.A(a)s4",
    "Table1.B.1",
    "Table1.B.2",
    "Table1.C",
    "Table1.D",
    "Table2(I)",
    "Table2(II)",
]


CRT1_PRY = {
    # Table1 instead of 1s1 and 1s2
    "Table3": {  # Agriculture summary
        "status": "tested",
        "table": {
            "firstrow": 8,
            "lastrow": 48,
            "header": ["entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": [
                "",
                "nan",
                '(1) "Total GHG emissions" does not include NOX, CO, NMVOC and SOX.',
            ],
            "unit_info": unit_info["industry"],
        },
        "sector_mapping": [
            ["3. Total agriculture", ["3"], 0],
            # A. Enteric fermentation
            ["3.A. Enteric fermentation", ["3.A"], 1],
            ["\\C!-CHL\\ 3.A.1. Cattle(3)", ["3.A.1"], 2],
            ["\\C!-CHL\\ Option A:", ["\\IGNORE"], 3],
            ["\\C-AUS\\ 3.A.1.a. Dairy cattle", ["\\IGNORE"], 4],
            ["\\C-AUS\\ 3.A.1.b. Non-dairy cattle", ["\\IGNRE"], 4],
            ["\\C!-AUS-CHL\\ 3.A.1.a. Dairy cattle", ["3.A.1.A.a"], 4],
            ["\\C!-AUS-CHL\\ 3.A.1.b. Non-dairy cattle", ["3.A.1.A.b"], 4],
            ["\\C-CHL\\ Option A:", ["\\IGNORE"], 2],  # 3.A.1 missing
            ["\\C-CHL\\ 3.A.1.a. Dairy cattle", ["3.A.1.A.a"], 3],
            ["\\C-CHL\\ 3.A.1.b. Non-dairy cattle", ["3.A.1.A.b"], 3],
            ["Option B (country-specific):", ["\\IGNORE"], 3],
            ["3.A.1.a. Other", ["3.A.1.B"], 4],
            ["3.A.1.a.i. Mature dairy cattle", ["3.A.1.B.a"], 5],
            ["3.A.1.a.ii. Other mature cattle", ["3.A.1.B.b"], 5],
            ["3.A.1.a.iii. Growing cattle", ["3.A.1.B.c"], 5],
            ["3.A.1.a.iv. Other (please specify)", ["3.A.1.B.d"], 5],
            # Other livestock
            ["3.A.2. Sheep", ["3.A.2"], 2],
            ["3.A.3. Swine", ["3.A.3"], 2],
            ["3.A.4. Other livestock", ["3.A.4"], 2],
            # Manure Management
            ["3.B. Manure management", ["3.B"], 1],
            ["3.B.1. Cattle(3)", ["3.B.1"], 2],
            ["Option A:", ["\\IGNORE"], 3],
            ["\\C-AUS\\ 3.B.1.a. Dairy cattle", ["\\IGNORE"], 4],
            ["\\C-AUS\\ 3.B.1.b. Non-dairy cattle", ["\\IGNORE"], 4],
            ["\\C!-AUS\\ 3.B.1.a. Dairy cattle", ["3.B.1.A.a"], 4],
            ["\\C!-AUS\\ 3.B.1.b. Non-dairy cattle", ["3.B.1.A.b"], 4],
            ["Option B (country-specific):", ["\\IGNORE"], 3],
            ["3.B.1.a. Other", ["3.B.1.B"], 4],
            ["3.B.1.a.i. Mature dairy cattle", ["3.B.1.B.a"], 5],
            ["3.B.1.a.ii. Other mature cattle", ["3.B.1.B.b"], 5],
            ["3.B.1.a.iii. Growing cattle", ["3.B.1.B.c"], 5],
            ["3.B.1.a.iv. Other (please specify)", ["3.B.1.B.d"], 5],
            ["3.B.2. Sheep", ["3.B.2"], 2],
            ["3.B.3. Swine", ["3.B.3"], 2],
            ["3.B.4. Other livestock", ["3.B.4"], 2],
            ["3.B.5. Indirect N2O emissions", ["3.B.5"], 2],
            ["3.C. Rice cultivation", ["3.C"], 1],
            ["3.D. Agricultural soils(4,5)", ["3.D"], 1],
            ["3.D.1. Direct N2O emissions from managed soils", ["3.D.a"], 2],
            ["3.D.1.a. Inorganic N fertilizers", ["3.D.a.1"], 3],
            ["3.D.1.b. Organic N fertilizers", ["3.D.a.2"], 3],
            ["3.D.1.c. Urine and dung deposited by grazing animals", ["3.D.a.3"], 3],
            ["3.D.1.d. Crop residues", ["3.D.a.4"], 3],
            [
                "3.D.1.e. Mineralization/immobilization associated with loss/gain of "
                "soil organic matter",
                ["3.D.a.5"],
                3,
            ],
            ["3.D.1.f. Cultivation of organic soils (i.e. histosols)", ["3.D.a.6"], 3],
            ["3.D.1.g. Other", ["3.D.a.7"], 3],
            ["3.D.2. Indirect N2O Emissions from managed soils", ["3.D.b"], 2],
            ["3.E. Prescribed burning of savannahs", ["3.E"], 1],
            ["3.F. Field burning of agricultural residues", ["3.F"], 1],
            ["3.G. Liming", ["3.G"], 1],
            ["3.H. Urea application", ["3.H"], 1],
            ["3.I. Other carbon-containing fertilizers", ["3.I"], 1],
            ["3.J. Other (please specify)", ["3.J"], 1],
            ["\\C-AUS-BRA-CHL-SGP\\ NA", ["\\IGNORE"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-GNB-KEN-LBN-MYS-MUS-URY-UZB-FRA\\ "
                "Other sources from agriculture (non-carbon pools) "
                "[IPCC Software 3.C.2 and 3.C.14]",
                ["3.J.2"],
                2,
            ],
            ["\\C-BLR-LTU\\ Other", ["3.J.2"], 2],
            ["\\C-DEU\\ Digestate renewable raw material (storage of N)", ["3.J.6"], 2],
            [
                "\\C-DEU\\ Digestate renewable raw material (atmospheric deposition)",
                ["3.J.7"],
                2,
            ],
            [
                "\\C-DEU\\ Digestate renewable raw material (storage of dry matter)",
                ["3.J.8"],
                2,
            ],
            ["\\C-DEU\\ 3.B NOx Emissions", ["3.J.1"], 2],
            ["\\C-AUT\\ NOx emissions from manure management", ["3.J.1"], 2],
            ["\\C-ESP\\ NOx 3B", ["3.J.1"], 2],
            ["\\C-NOR-DNK-SWE\\ NOx from manure management", ["3.J.1"], 2],
            ["\\C-IRL\\ NOx from Manure Management", ["3.J.1"], 2],
            ["\\C-COL\\ 3.B. NOx_Manure management", ["3.J.1"], 2],
            ["\\C-PRY\\ Total", ["\\IGNORE"], 2],
        ],
        "entity_mapping": {"Total GHG emissions (1)": f"KYOTOGHG ({gwp_to_use})"},
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table3.A": {  # Enteric fermentation
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 49,
            "header": ["entity", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Population size (1)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Average gross energy intake (GE)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Average CH4 conversion rate (Ym) (2)",
                "IMPLIED EMISSION FACTORS CH4",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) Parties are encouraged to provide detailed livestock population "
                "data by animal type and region, if available, in NID, and provide in "
                "the documentation box below a reference to the relevant section. Parties "
                "should use the same animal population statistics to estimate CH4 emissions "
                "from enteric fermentation, CH4 and N2O emissions from manure management, "
                "direct N2O emissions from soil and N2O emissions associated with manure "
                "production, as well as emissions from use of manure as fuel, and "
                "sewage-related emissions reported under the waste sector.",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["3.A.1. Cattle", ["3.A.1"], 0],
            ["Option A:", ["\\IGNORE"], 1],
            # AUS
            ["\\C-AUS\\ 3.A.1.a. Dairy cattle", ["\\IGNORE"], 2],
            ["\\C-AUS\\ 3.A.1.b. Non-dairy cattle", ["\\IGNORE"], 2],
            # other countries
            ["\\C!-AUS\\ 3.A.1.a. Dairy cattle", ["3.A.1.A.a"], 2],
            ["\\C!-AUS\\ 3.A.1.b. Non-dairy cattle", ["3.A.1.A.b"], 2],
            ["Option B (country-specific): (3)", ["\\IGNORE"], 1],
            ["3.A.1.a. Other", ["3.A.1.B"], 2],
            ["Drop-down list:", ["\\IGNORE"], 3],
            ["3.A.1.a.i. Mature dairy cattle", ["3.A.1.B.a"], 3],
            ["3.A.1.a.ii. Other mature cattle", ["3.A.1.B.b"], 3],
            ["3.A.1.a.iii. Growing cattle", ["3.A.1.B.c"], 3],
            ["3.A.1.a.iv. Other (please specify)", ["3.A.1.B.d"], 3],
            ["\\C-AUS\\ Dairy Cattle", ["3.A.1.B.d.AUS-i"], 4],
            ["\\C-AUS\\ Beef Cattle - Pasture", ["3.A.1.B.d.AUS-ii"], 4],
            ["\\C-AUS\\ Beef Cattle - Feedlot", ["3.A.1.C.d.AUS-iii"], 4],
            ["\\C-MLT\\ Bulls", ["3.A.1.B.d.MLT-i"], 4],
            ["\\C-MLT\\ Calves", ["3.A.1.B.d.MLT-ii"], 4],
            ["\\C-POL\\ Bulls (older than 2 years)", ["3.A.1.B.d.POL-i"], 4],
            [
                "\\C-POL\\ Non-dairy Heifers (older than 2 years)",
                ["3.A.1.B.d.POL-ii"],
                4,
            ],
            [
                "\\C-POL\\ Non-dairy Young Cattle (younger than 1 year)",
                ["3.A.1.C.d.POL-iii"],
                4,
            ],
            ["\\C-POL\\ Non-dairy Young Cattle (1-2 years)", ["3.A.1.C.d.POL-iv"], 4],
            ["\\C-POL\\ Dairy Cattle", ["3.A.1.C.d.POL-v"], 4],
            ["\\C-POL\\ Non-dairy Cattle", ["3.A.1.C.d.POL-vi"], 4],
            ["\\C-SVN\\ Non-dairy cattle", ["3.A.1.B.d.SVN-i"], 4],
            ["\\C-SVN\\ Other cows", ["3.A.1.B.d.SVN-ii"], 4],
            ["\\C-CHL\\ Dairy Cattle", ["3.A.1.B.d.CHL-i"], 4],
            ["\\C-CHL\\ Beef cattle", ["3.A.1.B.d.CHL-ii"], 4],
            ["\\C-CHL\\ Heifer", ["3.A.1.B.d.CHL-iii"], 4],
            ["\\C-CHL\\ Beef cattle (> 2 yr)", ["3.A.1.B.d.CHL-iv"], 4],
            ["\\C-CHL\\ Beef cattle (1 - 2 yr)", ["3.A.1.B.d.CHL-v"], 4],
            ["\\C-CHL\\ Calves", ["3.A.1.B.d.CHL-vi"], 4],
            [
                "\\C-COL\\ 3.A.1.a.i. High production dairy cattle",
                ["3.A.1.B.d.COL-i"],
                4,
            ],
            [
                "\\C-COL\\ 3.A.1.a.ii. Low production dairy cattle.",
                ["3.A.1.B.d.COL-ii"],
                4,
            ],
            ["\\C-COL\\ 3.A.1.a.iii. Beef cattle", ["3.A.1.B.d.COL-iii"], 4],
            ["\\C-COL\\ 3.A.1.a.iv. Breeding bulls.", ["3.A.1.B.d.COL-iv"], 4],
            ["\\C-COL\\ 3.A.1.a.v. Pre-weaning calves", ["3.A.1.B.d.COL-v"], 4],
            ["\\C-COL\\ 3.A.1.a.vi. Replacement heifers.", ["3.A.1.B.d.COL-vi"], 4],
            [
                "\\C-COL\\ 3.A.1.a.vii. Beef cattle o Feedlot cattle",
                ["3.A.1.B.d.COL-vii"],
                4,
            ],
            ["\\C-PAN\\ Low-yielding dairy cows", ["3.A.1.B.d.PAN-i"], 4],
            ["\\C-PAN\\ Dairy cattle (doble próposito)", ["3.A.1.B.d.PAN-ii"], 4],
            ["\\C-PAN\\ Young male bull (Novillos)", ["3.A.1.B.d.PAN-iii"], 4],
            ["\\C-PAN\\ Young calves (terneros)", ["3.A.1.B.d.PAN-iv"], 4],
            ["\\C-PAN\\ Bull", ["3.A.1.B.d.PAN-v"], 4],
            ["\\C-USA\\ Dairy cattle", ["3.A.1.B.d.USA-i"], 4],
            ["\\C-USA\\ Non-dairy cattle", ["3.A.1.B.d.USA-ii"], 4],
            ["\\C-USA\\ Dairy cows", ["3.A.1.B.d.USA-iii"], 4],
            ["\\C-USA\\ Heifer feedlot", ["3.A.1.B.d.USA-iv"], 4],
            ["\\C-USA\\ Steer feedlot", ["3.A.1.B.d.USA-v"], 4],
            ["\\C-USA\\ Beef replacements", ["3.A.1.B.d.USA-vi"], 4],
            ["\\C-USA\\ Dairy replacements", ["3.A.1.B.d.USA-vii"], 4],
            ["\\C-USA\\ Beef cows", ["3.A.1.B.d.USA-viii"], 4],
            ["\\C-USA\\ Heifer stocker", ["3.A.1.B.d.USA-ix"], 4],
            ["\\C-USA\\ Steer stocker", ["3.A.1.B.d.USA-x"], 4],
            ["\\C-USA\\ Bulls", ["3.A.1.B.d.USA-xi"], 4],
            ["\\C-USA\\ Dairy calves", ["3.A.1.B.d.USA-xii"], 4],
            ["\\C-USA\\ Beef calves", ["3.A.1.B.d.USA-xiii"], 4],
            ["3.A.2. Sheep", ["3.A.2"], 0],
            ["3.A.2.a. Other (please specify)", ["3.A.2.a"], 1],
            [
                "\\C-AUS-ITA-CHL-SRB-AUT-BLR-CHE-CZE-DNK-ESP-EST-FIN-GRC-HRV-JPN-KAZ-"
                "LIE-LTU-LVA-NOR-NZL-PRT-SVN-SWE-UKR\\ Sheep",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-ARG\\ All sheep", ["\\IGNORE"], 2],
            ["\\C-GHA-CHN\\ sheep", ["\\IGNORE"], 2],
            [
                "\\C-CHL-SRB-AUT-BLR-CHE-CZE-DNK-ESP-EST-FIN-GRC-HRV-JPN-KAZ-LIE-LTU-"
                "LVA-NOR-NZL-PRT-SVN-SWE-UKR\\ Sheep",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-BEL\\ Sheep unspecified", ["\\IGNORE"], 2],
            ["\\C-CAN\\ Sheep and Lamb", ["\\IGNORE"], 2],
            ["\\C-BRA\\ 3.A.2. Sheep", ["\\IGNORE"], 2],
            ["\\C-COL\\ 3.A.2.a.i. Sheep", ["\\IGNORE"], 2],
            ["\\C-ITA-NLD\\ Sheep (2)", ["\\IGNORE"], 2],
            ["\\C-NLD\\ Sheep (8)", ["\\IGNORE"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-"
                "UZB-FRA\\ All sheep [IPCC Software 3.A.1.c]",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 2],
            ["\\C-MLT\\ Growing Lambs", ["3.A.2.a.MLT-i"], 2],
            ["\\C-MLT\\ Other Mature Ewes", ["3.A.2.a.MLT-ii"], 2],
            ["\\C-MLT\\ Mature Ewes", ["3.A.2.a.MLT-iii"], 2],
            ["\\C-SVK\\ Mature ewes", ["3.A.2.a.SVK-i"], 2],
            ["\\C-SVK\\ Growing lambs", ["3.A.2.a.SVK-ii"], 2],
            ["\\C-SVK\\ Other mature sheeps", ["3.A.2.a.SVK-iii"], 2],
            ["\\C-TUR\\ Domestic sheep", ["3.A.2.a.TUR-i"], 2],
            ["\\C-TUR\\ Merino sheep", ["3.A.2.a.TUR-ii"], 2],
            ["\\C-DZA\\ dairy Sheep", ["3.A.2.a.DZA-i"], 2],
            ["\\C-DZA\\ Other Sheep", ["3.A.2.a.DZA-ii"], 2],
            ["\\C-IRL\\ Ewes Lowland", ["3.A.2.a.IRL-i"], 2],
            ["\\C-IRL\\ Ewes Upland", ["3.A.2.a.IRL-ii"], 2],
            ["\\C-IRL\\ Lambs Lowland", ["3.A.2.a.IRL-iii"], 2],
            ["\\C-IRL\\ Lambs Upland", ["3.A.2.a.IRL-iv"], 2],
            ["\\C-IRL\\ Other Sheep>1yr Lowland", ["3.A.2.a.IRL-v"], 2],
            ["\\C-IRL\\ Other Sheep>1yr Upland", ["3.A.2.a.IRL-vi"], 2],
            ["\\C-IRL\\ Rams Lowland", ["3.A.2.a.IRL-vii"], 2],
            ["\\C-IRL\\ Rams Upland", ["3.A.2.a.IRL-viii"], 2],
            ["\\C-ISL\\ Mature ewes", ["3.A.2.a.ISL-i"], 2],
            ["\\C-ISL\\ Animal for replacement", ["3.A.2.a.ISL-ii"], 2],
            ["\\C-ISL\\ Other mature sheep", ["3.A.2.a.ISL-iii"], 2],
            ["\\C-ISL\\ Lambs", ["3.A.2.a.ISL-iv"], 2],
            ["\\C-USA\\ Sheep", ["3.A.2.a.USA-i"], 2],
            ["\\C-USA\\ Sheep on feed", ["3.A.2.a.USA-ii"], 2],
            ["\\C-USA\\ Sheep not on feed", ["3.A.2.a.USA-iii"], 2],
            ["3.A.3. Swine", ["3.A.3"], 0],
            ["3.A.3.a. Other (please specify)", ["3.A.3.a"], 1],
            ["\\C-AUS-ITA-CAN\\ Swine", ["\\IGNORE"], 2],
            ["\\C-NZL\\ Pigs", ["\\IGNORE"], 2],
            ["\\C-ARG\\ All swine", ["\\IGNORE"], 2],
            [
                "\\C-GHA-SRB-AUT-BLR-CHE-CZE-EST-FIN-GRC-JPN-KAZ-LIE-LTU-LVA-NOR-PRT-"
                "SVN-SWE-TUR-UKR-CHN\\ Swine",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-BEL\\ Swine unspecified", ["\\IGNORE"], 2],
            ["\\C-BRA\\ 3.A.3. Swine", ["\\IGNORE"], 2],
            ["\\C-ITA-NLD\\ Swine (3)", ["\\IGNORE"], 2],
            ["\\C-NLD\\ Swine (7)", ["\\IGNORE"], 2],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-"
                "UZB-FRA\\ All swine [IPCC Software 3.A.1.h]",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 2],
            ["\\C-ESP\\ White swine (finishing/fattening pigs)", ["3.A.3.a.ESP-i"], 2],
            ["\\C-ESP\\ White swine (sows)", ["3.A.3.a.ESP-ii"], 2],
            [
                "\\C-ESP\\ Iberian swine (finishing/fattening pigs)",
                ["3.A.3.a.ESP-iii"],
                2,
            ],
            ["\\C-ESP\\ Iberian swine (sows)", ["3.A.3.a.ESP-iv"], 2],
            ["\\C-MLT\\ Breeding boars", ["3.A.3.a.MLT-i"], 2],
            ["\\C-MLT\\ Breeding females - gilts", ["3.A.3.a.MLT-ii"], 2],
            ["\\C-MLT\\ Breeding female - sows", ["3.A.3.a.MLT-iii"], 2],
            ["\\C-MLT\\ Fattening pigs more than 50kg", ["3.A.3.a.MLT-iv"], 2],
            ["\\C-MLT\\ Young pigs 20-50kg", ["3.A.3.a.MLT-v"], 2],
            ["\\C-MLT\\ Piglets less than 20kg", ["3.A.3.a.MLT-vi"], 2],
            ["\\C-SVK-HRV\\ Breeding swine", ["3.A.3.a.SVK-i"], 2],
            ["\\C-SVK-HRV\\ Market swine", ["3.A.3.a.SVK-ii"], 2],
            ["\\C-CHL\\ Pigs", ["3.A.3.a.CHL-i"], 2],
            ["\\C-CHL\\ Boars", ["3.A.3.a.CHL-ii"], 2],
            ["\\C-CHL\\ Juvenile pigs", ["3.A.3.a.CHL-iii"], 2],
            ["\\C-COL\\ 3.A.3.a.i. swine < 6 months", ["3.A.3.a.COL-i"], 2],
            ["\\C-COL\\ 3.A.3.a.ii. swine > 6 months", ["3.A.3.a.COL-ii"], 2],
            ["\\C-COL\\ 3.A.3.a.iii. Low productivity swine", ["3.A.3.a.COL-iii"], 2],
            ["\\C-DNK\\ Sows", ["3.A.3.a.DNK-i"], 2],
            ["\\C-DNK\\ Fattening pigs", ["3.A.3.a.DNK-ii"], 2],
            ["\\C-DNK\\ Weaners", ["3.A.3.a.DNK-iii"], 2],
            ["\\C-IRL\\ Boars", ["3.A.3.a.IRL-i"], 2],
            ["\\C-IRL\\ Sows in Pig", ["3.A.3.a.IRL-ii"], 2],
            ["\\C-IRL\\ Gilts in Pig", ["3.A.3.a.IRL-iii"], 2],
            ["\\C-IRL\\ Pigs > 20kg", ["3.A.3.a.IRL-iv"], 2],
            ["\\C-IRL\\ Pigs < 20kg", ["3.A.3.a.IRL-v"], 2],
            ["\\C-IRL\\ Other Sows for Breeding", ["3.A.3.a.IRL-vi"], 2],
            ["\\C-IRL\\ Gilts not yet Served", ["3.A.3.a.IRL-vii"], 2],
            ["\\C-ISL\\ Piglets", ["3.A.3.a.ISL-i"], 2],
            ["\\C-ISL\\ Sows", ["3.A.3.a.ISL-ii"], 2],
            ["\\C-USA\\ Swine", ["3.A.3.a.USA-i"], 2],
            ["\\C-USA\\ Market swine less than 50 lb", ["3.A.3.a.USA-ii"], 2],
            ["\\C-USA\\ Market swine 50-119 lb", ["3.A.3.a.USA-iii"], 2],
            ["\\C-USA\\ Market swine 120-179 lb", ["3.A.3.a.USA-iv"], 2],
            ["\\C-USA\\ Market swine greater than 180 lb", ["3.A.3.a.USA-v"], 2],
            ["\\C-USA\\ Breeding swine", ["3.A.3.a.USA-vi"], 2],
            # other livestock
            ["\\C!-AUS-CHL\\ 3.A.4. Other livestock(4)", ["3.A.4"], 0],
            ["\\C-AUS\\ 3.A.4. Other livestock (4)", ["3.A.4"], 0],
            ["\\C-CHL\\ 3.A.4. Other livestock (please specify) (4)", ["3.A.4"], 0],
            ["\\C-AUS-CHL\\ Drop down list:", ["\\IGNORE"], 1],
            ["3.A.4.a. Buffalo", ["3.A.4.a"], 1],
            ["3.A.4.b. Camels", ["3.A.4.b"], 1],
            ["3.A.4.c. Deer", ["3.A.4.c"], 1],
            ["3.A.4.d. Goats", ["3.A.4.d"], 1],
            ["3.A.4.e. Horses", ["3.A.4.e"], 1],
            ["3.A.4.f. Mules and asses", ["3.A.4.f"], 1],
            ["3.A.4.g. Poultry", ["3.A.4.g"], 1],
            ["\\C!-CHL\\ 3.A.4.h. Other", ["3.A.4.h"], 1],
            ["\\C-CHL\\ 3.A.4.h. Other (please specify)", ["3.A.4.h"], 1],
            ["\\C-AUS\\ Drop-down list:", ["\\IGNORE"], 2],
            ["3.A.4.h.i. Rabbit", ["3.A.4.h.i"], 2],
            ["3.A.4.h.ii. Reindeer", ["3.A.4.h.ii"], 2],
            ["3.A.4.h.iii. Ostrich", ["3.A.4.h.iii"], 2],
            ["3.A.4.h.iv. Fur-bearing animals (5)", ["3.A.4.h.iv"], 2],
            ["\\C!-CHL\\ 3.A.4.h.v. Other (please specify)", ["3.A.4.h.v"], 2],
            ["\\C-CHL\\ 3.A.4.h.v. Other (please specity)", ["3.A.4.h.v"], 2],
            ["\\C-AUS\\ Alpacas", ["3.A.4.h.v.1"], 3],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " Alpacas [IPCC Software 3.A.1.j]",
                ["3.A.4.h.v.1"],
                3,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " Llamas [IPCC Software 3.A.1.j]",
                ["3.A.4.h.v.2"],
                3,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " All other species [IPCC Software 3.A.1.j]",
                ["3.A.4.h.v.10"],
                3,
            ],
            ["\\C-SGP\\ Quail", ["3.A.4.h.v.3"], 3],
            ["\\C-ESP\\ Ducks and other poultry", ["3.A.4.h.v.4"], 3],
            ["\\C-ESP\\ Turkeys", ["3.A.4.h.v.5"], 3],
            ["\\C-ESP\\ Broilers", ["3.A.4.h.v.6"], 3],
            ["\\C-CHE\\ Livestock outside agriculture", ["3.A.4.h.v.11"], 3],
            ["\\C-COL\\ 3.A.4.g.i. Laying hens", ["3.A.4.h.v.12"], 3],
            ["\\C-COL\\ 3.A.4.g.ii. broiler chicken", ["3.A.4.h.v.13"], 3],
            ["\\C-CAN\\ Wild Boar", ["3.A.4.h.v.14"], 3],
            ["\\C-CHL\\ Wild boars", ["3.A.4.h.v.14"], 3],
            ["\\C-DNK\\ Pheasants", ["3.A.4.h.v.15"], 3],
            ["\\C-LTU\\ Nutria", ["3.A.4.h.v.16"], 3],
            ["\\C-USA\\ American bison", ["3.A.4.h.v.17"], 3],
            ["\\C-CHL\\ Llamas, alpacas, huarizos", ["3.A.4.h.v.18"], 3],
        ],
        "entity_mapping": {"EMISSIONS CH4": "CH4"},
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table3.B(a)": {  # Manure management CH4
        "status": "tested",
        "table": {
            "firstrow": 6,
            "lastrow": 52,
            "header": ["entity", "entity", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Population size",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Allocation by climate region (1) Cool",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Allocation by climate region (1) Temperate",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Allocation by climate region (1) Warm",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Typical animal mass (average) Warm",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION VS(2) daily excretion (average) Warm",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION CH4 producing potential (Bo) (2) (average) Warm",
                "IMPLIED EMISSION FACTORS CH4 producing potential (Bo) (2) (average) CH4",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) Climate regions are defined in terms of annual average temperature as "
                "follows: cool = less than 15 °C; temperate = 15–25 °C inclusive; and warm "  # noqa: RUF001
                "= higher than 25 °C (see table 10.17, chap. 10, vol. 4 of the 2006 IPCC "
                "Guidelines).",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["3.B.1. Cattle", ["3.B.1"], 0],
            ["Option A:", ["\\IGNORE"], 1],
            # AUS
            ["\\C-AUS\\ 3.B.1.a. Dairy cattle", ["\\IGNORE"], 2],
            ["\\C-AUS\\ 3.B.1.b. Non-dairy cattle", ["\\IGNORE"], 2],
            # other countries
            ["\\C!-AUS\\ 3.B.1.a. Dairy cattle", ["3.B.1.A.a"], 2],
            ["\\C!-AUS\\ 3.B.1.b. Non-dairy cattle", ["3.B.1.A.b"], 2],
            ["Option B (country-specific): (3)", ["\\IGNORE"], 1],
            ["3.B.1.a. Other", ["3.B.1.B"], 2],
            ["Drop down list:", ["\\IGNORE"], 3],
            ["3.B.1.a.i. Mature dairy cattle", ["3.B.1.B.a"], 3],
            ["3.B.1.a.ii. Other mature cattle", ["3.B.1.B.b"], 3],
            ["3.B.1.a.iii. Growing cattle", ["3.B.1.B.c"], 3],
            ["3.B.1.a.iv. Other (please specify)", ["3.B.1.B.d"], 3],
            ["\\C-AUS\\ Dairy Cattle", ["3.B.1.B.d.AUS-i"], 4],
            ["\\C-AUS\\ Beef Cattle - Pasture", ["3.B.1.B.d.AUS-ii"], 4],
            ["\\C-AUS\\ Beef Cattle - Feedlot", ["3.B.1.C.d.AUS-iii"], 4],
            ["\\C-MLT\\ Bulls", ["3.B.1.B.d.MLT-i"], 4],
            ["\\C-MLT\\ Calves", ["3.B.1.B.d.MLT-ii"], 4],
            ["\\C-POL\\ Bulls (older than 2 years)", ["3.B.1.B.d.POL-i"], 4],
            [
                "\\C-POL\\ Non-dairy Heifers (older than 2 years)",
                ["3.B.1.B.d.POL-ii"],
                4,
            ],
            [
                "\\C-POL\\ Non-dairy Young Cattle (younger than 1 year)",
                ["3.B.1.C.d.POL-iii"],
                4,
            ],
            ["\\C-POL\\ Non-dairy Young Cattle (1-2 years)", ["3.B.1.C.d.POL-iv"], 4],
            ["\\C-POL\\ Dairy Cattle", ["3.B.1.C.d.POL-v"], 4],
            ["\\C-POL\\ Non-dairy Cattle", ["3.B.1.C.d.POL-vi"], 4],
            ["\\C-SVN\\ Non-dairy cattle", ["3.B.1.B.d.SVN-i"], 4],
            ["\\C-SVN\\ Other cows", ["3.B.1.B.d.SVN-ii"], 4],
            ["\\C-CHL\\ Dairy Cattle", ["3.B.1.B.d.CHL-i"], 4],
            ["\\C-CHL\\ Beef cattle", ["3.B.1.B.d.CHL-ii"], 4],
            ["\\C-CHL\\ Heifer", ["3.B.1.B.d.CHL-iii"], 4],
            ["\\C-CHL\\ Beef cattle (> 2 yr)", ["3.B.1.B.d.CHL-iv"], 4],
            ["\\C-CHL\\ Beef cattle (1 - 2 yr)", ["3.B.1.B.d.CHL-v"], 4],
            ["\\C-CHL\\ Calves", ["3.B.1.B.d.CHL-vi"], 4],
            [
                "\\C-COL\\ 3.B.1.a.i. High production dairy cattle",
                ["3.B.1.B.d.COL-i"],
                4,
            ],
            [
                "\\C-COL\\ 3.B.1.a.ii. Low production dairy cattle.",
                ["3.B.1.B.d.COL-ii"],
                4,
            ],
            ["\\C-COL\\ 3.B.1.a.iii. Beef cattle", ["3.B.1.B.d.COL-iii"], 4],
            ["\\C-COL\\ 3.B.1.a.iv. Breeding bulls.", ["3.B.1.B.d.COL-iv"], 4],
            ["\\C-COL\\ 3.B.1.a.v. Pre-weaning calves", ["3.B.1.B.d.COL-v"], 4],
            ["\\C-COL\\ 3.B.1.a.vi. Replacement heifers.", ["3.B.1.B.d.COL-vi"], 4],
            [
                "\\C-COL\\ 3.B.1.a.vii. Beef cattle o Feedlot cattle",
                ["3.B.1.B.d.COL-vii"],
                4,
            ],
            # error in panama tables. Young calves present twice, others shifted
            # ["\\C-PAN\\ High production dairy cows", ["3.B.1.B.d.PAN-i"], 4],
            # ["\\C-PAN\\ Low-yielding dairy cows", ["3.B.1.B.d.PAN-i"], 4],
            # ["\\C-PAN\\ Dairy cattle (doble próposito)", ["3.B.1.B.d.PAN-ii"], 4],
            # ["\\C-PAN\\ Young male bull (Novillos)", ["3.B.1.B.d.PAN-iii"], 4],
            # ["\\C-PAN\\ Young calves (terneros)", ["3.B.1.B.d.PAN-iv"], 4],
            # ["\\C-PAN\\ Bull", ["3.B.1.B.d.PAN-v"], 4],
            ["\\C-PAN\\ High production dairy cows", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Low-yielding dairy cows", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Dairy cattle (doble próposito)", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Young male bull (Novillos)", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Young calves (terneros)", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Bull", ["\\IGNORE"], 4],
            ["\\C-USA\\ Dairy cattle", ["3.B.1.B.d.USA-i"], 4],
            ["\\C-USA\\ Non-dairy cattle", ["3.B.1.B.d.USA-ii"], 4],
            ["\\C-USA\\ Dairy cows", ["3.B.1.B.d.USA-iii"], 4],
            ["\\C-USA\\ Heifer feedlot", ["3.B.1.B.d.USA-iv"], 4],
            ["\\C-USA\\ Steer feedlot", ["3.B.1.B.d.USA-v"], 4],
            ["\\C-USA\\ Beef replacements", ["3.B.1.B.d.USA-vi"], 4],
            ["\\C-USA\\ Dairy replacements", ["3.B.1.B.d.USA-vii"], 4],
            ["\\C-USA\\ Beef cows", ["3.B.1.B.d.USA-viii"], 4],
            ["\\C-USA\\ Heifer stocker", ["3.B.1.B.d.USA-ix"], 4],
            ["\\C-USA\\ Steer stocker", ["3.B.1.B.d.USA-x"], 4],
            ["\\C-USA\\ Bulls", ["3.B.1.B.d.USA-xi"], 4],
            ["\\C-USA\\ Dairy calves", ["3.B.1.B.d.USA-xii"], 4],
            ["\\C-USA\\ Beef calves", ["3.B.1.B.d.USA-xiii"], 4],
            ["3.B.2. Sheep", ["3.B.2"], 0],
            ["3.B.2.a. Other (please specify)", ["3.B.2.a"], 1],
            ["\\C-AUS-ITA\\ Sheep", ["\\IGNORE"], 2],
            ["\\C-ARG\\ All sheep", ["\\IGNORE"], 2],
            ["\\C-GHA-CHN\\ sheep", ["\\IGNORE"], 2],
            [
                "\\C-CHL-COL-PAN-SRB-AUT-BLR-CHE-CZE-DNK-ESP-EST-FIN-GRC-HRV-JPN-KAZ-"
                "LIE-LTU-LVA-NLD-NOR-NZL-PRT-SVN-SWE-UKR\\ Sheep",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-BEL\\ Sheep unspecified", ["\\IGNORE"], 2],
            ["\\C-CAN\\ Sheep and Lamb", ["\\IGNORE"], 2],
            ["\\C-BRA\\ 3.B.2. Sheep", ["\\IGNORE"], 2],
            ["\\C-COL\\ 3.B.2.a.i. Sheep", ["\\IGNORE"], 2],
            ["\\C-ITA-NLD\\ Sheep (2)", ["\\IGNORE"], 2],
            ["\\C-NLD\\ Sheep (8)", ["\\IGNORE"], 2],
            [
                "\\C-AZE-BTN-BRN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-URY-"
                "UZB-FRA\\ All sheep [IPCC Software 3.A.2.c]",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 2],
            ["\\C-MLT\\ Growing Lambs", ["3.B.2.a.MLT-i"], 2],
            ["\\C-MLT\\ Other Mature Ewes", ["3.B.2.a.MLT-ii"], 2],
            ["\\C-MLT\\ Mature Ewes", ["3.B.2.a.MLT-iii"], 2],
            ["\\C-SVK\\ Mature ewes", ["3.B.2.a.SVK-i"], 2],
            ["\\C-SVK\\ Growing lambs", ["3.B.2.a.SVK-ii"], 2],
            ["\\C-SVK\\ Other mature sheeps", ["3.B.2.a.SVK-iii"], 2],
            ["\\C-TUR\\ Domestic sheep", ["3.B.2.a.TUR-i"], 2],
            ["\\C-TUR\\ Merino sheep", ["3.B.2.a.TUR-ii"], 2],
            ["\\C-DZA\\ dairy Sheep", ["3.B.2.a.DZA-i"], 2],
            ["\\C-DZA\\ Other Sheep", ["3.B.2.a.DZA-ii"], 2],
            ["\\C-IRL\\ Ewes Lowland", ["3.B.2.a.IRL-i"], 2],
            ["\\C-IRL\\ Ewes Upland", ["3.B.2.a.IRL-ii"], 2],
            ["\\C-IRL\\ Lambs Lowland", ["3.B.2.a.IRL-iii"], 2],
            ["\\C-IRL\\ Lambs Upland", ["3.B.2.a.IRL-iv"], 2],
            ["\\C-IRL\\ Other Sheep>1yr Lowland", ["3.B.2.a.IRL-v"], 2],
            ["\\C-IRL\\ Other Sheep>1yr Upland", ["3.B.2.a.IRL-vi"], 2],
            ["\\C-IRL\\ Rams Lowland", ["3.B.2.a.IRL-vii"], 2],
            ["\\C-IRL\\ Rams Upland", ["3.B.2.a.IRL-viii"], 2],
            ["\\C-ISL\\ Mature ewes", ["3.B.2.a.ISL-i"], 2],
            ["\\C-ISL\\ Animal for replacement", ["3.B.2.a.ISL-ii"], 2],
            ["\\C-ISL\\ Other mature sheep", ["3.B.2.a.ISL-iii"], 2],
            ["\\C-ISL\\ Lambs", ["3.B.2.a.ISL-iv"], 2],
            ["\\C-USA\\ Sheep", ["3.B.2.a.USA-i"], 2],
            ["\\C-USA\\ Sheep on feed", ["3.B.2.a.USA-ii"], 2],
            ["\\C-USA\\ Sheep not on feed", ["3.B.2.a.USA-iii"], 2],
            ["3.B.3. Swine", ["3.B.3"], 0],
            ["3.B.3.a. Other (please specify)", ["3.B.3.a"], 1],
            ["\\C-AUS-ITA-CAN\\ Swine", ["\\IGNORE"], 2],
            ["\\C-NZL\\ Pigs", ["\\IGNORE"], 2],
            ["\\C-ARG\\ All swine", ["\\IGNORE"], 2],
            [
                "\\C-GHA-PAN-SRB-AUT-BLR-CHE-CZE-EST-FIN-GRC-JPN-KAZ-LIE-LTU-LVA-NLD-"
                "NOR-PRT-SVN-SWE-TUR-UKR-CHN\\ Swine",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-BEL\\ Swine unspecified", ["\\IGNORE"], 2],
            ["\\C-ITA-NLD\\ Swine (3)", ["\\IGNORE"], 2],
            ["\\C-BRA\\ 3.B.3. Swine", ["\\IGNORE"], 2],
            ["\\C-NLD\\ Swine (7)", ["\\IGNORE"], 2],
            [
                "\\C-AZE-BTN-BRN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-URY-"
                "UZB-FRA\\ All swine [IPCC Software 3.A.2.h]",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 2],
            ["\\C-ESP\\ White swine (finishing/fattening pigs)", ["3.B.3.a.ESP-i"], 2],
            ["\\C-ESP\\ White swine (sows)", ["3.B.3.a.ESP-ii"], 2],
            [
                "\\C-ESP\\ Iberian swine (finishing/fattening pigs)",
                ["3.B.3.a.ESP-iii"],
                2,
            ],
            ["\\C-ESP\\ Iberian swine (sows)", ["3.B.3.a.ESP-iv"], 2],
            ["\\C-MLT\\ Breeding boars", ["3.B.3.a.MLT-i"], 2],
            ["\\C-MLT\\ Breeding females - gilts", ["3.B.3.a.MLT-ii"], 2],
            ["\\C-MLT\\ Breeding female - sows", ["3.B.3.a.MLT-iii"], 2],
            ["\\C-MLT\\ Fattening pigs more than 50kg", ["3.B.3.a.MLT-iv"], 2],
            ["\\C-MLT\\ Young pigs 20-50kg", ["3.B.3.a.MLT-v"], 2],
            ["\\C-MLT\\ Piglets less than 20kg", ["3.B.3.a.MLT-vi"], 2],
            ["\\C-SVK-HRV\\ Breeding swine", ["3.B.3.a.SVK-i"], 2],
            ["\\C-SVK-HRV\\ Market swine", ["3.B.3.a.SVK-ii"], 2],
            ["\\C-CHL\\ Pigs", ["3.B.3.a.CHL-i"], 2],
            ["\\C-CHL\\ Boars", ["3.B.3.a.CHL-ii"], 2],
            ["\\C-CHL\\ Juvenile pigs", ["3.B.3.a.CHL-iii"], 2],
            ["\\C-COL\\ 3.B.3.a.i. Swines < 6 month", ["3.B.3.a.COL-i"], 2],
            ["\\C-COL\\ 3.B.3.a.ii. Swines > 6 month", ["3.B.3.a.COL-ii"], 2],
            ["\\C-COL\\ 3.B.3.a.iii. Low productivity swine", ["3.B.3.a.COL-iii"], 2],
            ["\\C-DNK\\ Sows", ["3.B.3.a.DNK-i"], 2],
            ["\\C-DNK\\ Fattening pigs", ["3.B.3.a.DNK-ii"], 2],
            ["\\C-DNK\\ Weaners", ["3.B.3.a.DNK-iii"], 2],
            ["\\C-IRL\\ Boars", ["3.B.3.a.IRL-i"], 2],
            ["\\C-IRL\\ Sows in Pig", ["3.B.3.a.IRL-ii"], 2],
            ["\\C-IRL\\ Gilts in Pig", ["3.B.3.a.IRL-iii"], 2],
            ["\\C-IRL\\ Pigs > 20kg", ["3.B.3.a.IRL-iv"], 2],
            ["\\C-IRL\\ Pigs < 20kg", ["3.B.3.a.IRL-v"], 2],
            ["\\C-IRL\\ Other Sows for Breeding", ["3.B.3.a.IRL-vi"], 2],
            ["\\C-IRL\\ Gilts not yet Served", ["3.B.3.a.IRL-vii"], 2],
            ["\\C-ISL\\ Piglets", ["3.B.3.a.ISL-i"], 2],
            ["\\C-ISL\\ Sows", ["3.B.3.a.ISL-ii"], 2],
            ["\\C-USA\\ Swine", ["3.B.3.a.USA-i"], 2],
            ["\\C-USA\\ Market swine less than 50 lb", ["3.B.3.a.USA-ii"], 2],
            ["\\C-USA\\ Market swine 50-119 lb", ["3.B.3.a.USA-iii"], 2],
            ["\\C-USA\\ Market swine 120-179 lb", ["3.B.3.a.USA-iv"], 2],
            ["\\C-USA\\ Market swine greater than 180 lb", ["3.B.3.a.USA-v"], 2],
            ["\\C-USA\\ Breeding swine", ["3.B.3.a.USA-vi"], 2],
            # other livestock
            # ["\\C!-AUS-CHL\\ 3.B.4. Other livestock(4)", ["3.B.4"], 0],
            # ["\\C-AUS-ARG-AZE-\\ 3.B.4. Other livestock (4)", ["3.B.4"], 0],
            # ["\\C-CHL\\ 3.B.4. Other livestock (please specify) (4)", ["3.B.4"], 0],
            ["3.B.4. Other livestock (4)", ["3.B.4"], 0],
            ["\\C-AUS-CHL\\ Drop-down list:", ["\\IGNORE"], 1],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 1],
            ["3.B.4.a. Buffalo", ["3.B.4.a"], 1],
            ["3.B.4.b. Camels", ["3.B.4.b"], 1],
            ["3.B.4.c. Deer", ["3.B.4.c"], 1],
            ["3.B.4.d. Goats", ["3.B.4.d"], 1],
            ["3.B.4.e. Horses", ["3.B.4.e"], 1],
            ["3.B.4.f. Mules and Asses", ["3.B.4.f"], 1],
            ["3.B.4.g. Poultry", ["3.B.4.g"], 1],
            ["\\C!-CHL\\ 3.B.4.h. Other", ["3.B.4.h"], 1],
            ["\\C-CHL\\ 3.B.4.h. Other (please specify)", ["3.B.4.h"], 1],
            ["\\C-AUS\\ Drop-down list:", ["\\IGNORE"], 2],
            ["3.B.4.h.i. Rabbit", ["3.B.4.h.i"], 2],
            ["3.B.4.h.ii. Reindeer", ["3.B.4.h.ii"], 2],
            ["3.B.4.h.iii. Ostrich", ["3.B.4.h.iii"], 2],
            ["3.B.4.h.iv. Fur-bearing animals (5)", ["3.B.4.h.iv"], 2],
            ["\\C!-CHL\\ 3.B.4.h.v. Other (please specify)", ["3.B.4.h.v"], 2],
            ["\\C-CHL\\ 3.B.4.h.v. Other (please specity)", ["3.B.4.h.v"], 2],
            ["\\C-AUS\\ Alpacas", ["3.B.4.h.v.1"], 3],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " Alpacas [IPCC Software 3.A.2.j]",
                ["3.B.4.h.v.1"],
                3,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " Llamas [IPCC Software 3.A.2.j]",
                ["3.B.4.h.v.2"],
                3,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " All other species [IPCC Software 3.A.2.j]",
                ["3.B.4.h.v.10"],
                3,
            ],
            ["\\C-SGP\\ Quail", ["3.B.4.h.v.3"], 3],
            ["\\C-ESP\\ Ducks and other poultry", ["3.B.4.h.v.4"], 3],
            ["\\C-ESP\\ Turkeys", ["3.B.4.h.v.5"], 3],
            ["\\C-ESP\\ Broilers", ["3.B.4.h.v.6"], 3],
            ["\\C-CHE\\ Livestock outside agriculture", ["3.B.4.h.v.11"], 3],
            ["\\C-COL\\ 3.B.4.g.i. Laying hens", ["3.B.4.h.v.12"], 3],
            ["\\C-COL\\ 3.B.4.g.ii. broiler chicken", ["3.B.4.h.v.13"], 3],
            ["\\C-CAN\\ Wild Boar", ["3.B.4.h.v.14"], 3],
            ["\\C-CHL\\ Wild boars", ["3.B.4.h.v.14"], 3],
            ["\\C-DNK\\ Pheasants", ["3.B.4.h.v.15"], 3],
            ["\\C-LTU\\ Nutria", ["3.B.4.h.v.16"], 3],
            ["\\C-USA\\ American bison", ["3.B.4.h.v.17"], 3],
            ["\\C-CHL\\ Llamas, alpacas, huarizos", ["3.B.4.h.v.18"], 3],
        ],
        "entity_mapping": {
            "EMISSIONS CH4 producing potential (Bo) (2) (average) CH4": "CH4"
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table3.B(b)": {  # Manure management N2O
        "status": "tested",
        "table": {
            "firstrow": 5,
            "lastrow": 48,  # don't read indirect emissions as we have them from
            # Table3 and reading them makes the specification very complicated
            "header": ["entity", "entity", "entity", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Population size (1000s)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion rate "
                "(kg N/ head/yr)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Typical animal mass "
                "(average) (kg/ head)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Anaerobic lagoon",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Liquid system",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Daily spread",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Solid storage",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Pit storage",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Dry lot",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Deep bedding",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Pasture range and paddock (1)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Composting",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Digesters",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Burned for fuel or as waste (2)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen excretion per "
                "manure management system (MMS) (kg N/yr) Other (3)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Total N excreted Other (3)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Total N volatilised as "
                "NH3, NOX and N2 (4)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION N lost through leaching "
                "and run-off",
                "IMPLIED EMISSION FACTORS Emission factor per animals Direct and run-off",
                "IMPLIED EMISSION FACTORS Emission factor per animals Indirect "
                "Atmospheric deposition",
                "IMPLIED EMISSION FACTORS Emission factor per animals Indirect "
                "Nitrogen leaching and run-off",
                "EMISSIONS N2O Indirect Atmospheric deposition",
                "EMISSIONS N2O Indirect Nitrogen leaching and run-off",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) Direct and indirect N2O emissions associated with the manure "
                "deposited on agricultural soils or pasture, range and paddock systems "
                "are included under N2O emissions from managed soils (see table "
                "3(III).D-E).",
                "3.B.5. Indirect N2O emissions",
                "Total N handled per MMS (kg N/year)",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["3.B.1. Cattle", ["3.B.1"], 0],
            ["Option A:", ["\\IGNORE"], 1],
            # AUS
            ["\\C-AUS\\ 3.B.1.a. Dairy cattle", ["\\IGNORE"], 2],
            ["\\C-AUS\\ 3.B.1.b. Non-dairy cattle", ["\\IGNORE"], 2],
            # other countries
            ["\\C!-AUS\\ 3.B.1.a. Dairy cattle", ["3.B.1.A.a"], 2],
            ["\\C!-AUS\\ 3.B.1.b. Non-dairy cattle", ["3.B.1.A.b"], 2],
            ["Option B (country-specific): (5)", ["\\IGNORE"], 1],
            ["3.B.1.a. Other", ["3.B.1.B"], 2],
            ["\\C-AUS-ECU\\ Drop-down list", ["\\IGNORE"], 3],
            ["3.B.1.a.i. Mature dairy cattle", ["3.B.1.B.a"], 3],
            ["3.B.1.a.ii. Other mature cattle", ["3.B.1.B.b"], 3],
            ["3.B.1.a.iii. Growing cattle", ["3.B.1.B.c"], 3],
            ["3.B.1.a.iv. Other (please specify)", ["3.B.1.B.d"], 3],
            ["\\C-AUS\\ Dairy Cattle", ["3.B.1.B.d.AUS-i"], 4],
            ["\\C-AUS\\ Beef Cattle - Pasture", ["3.B.1.B.d.AUS-ii"], 4],
            ["\\C-AUS\\ Beef Cattle - Feedlot", ["3.B.1.C.d.AUS-iii"], 4],
            ["\\C-MLT\\ Bulls", ["3.B.1.B.d.MLT-i"], 4],
            ["\\C-MLT\\ Calves", ["3.B.1.B.d.MLT-ii"], 4],
            ["\\C-POL\\ Bulls (older than 2 years)", ["3.B.1.B.d.POL-i"], 4],
            [
                "\\C-POL\\ Non-dairy Heifers (older than 2 years)",
                ["3.B.1.B.d.POL-ii"],
                4,
            ],
            [
                "\\C-POL\\ Non-dairy Young Cattle (younger than 1 year)",
                ["3.B.1.C.d.POL-iii"],
                4,
            ],
            ["\\C-POL\\ Non-dairy Young Cattle (1-2 years)", ["3.B.1.C.d.POL-iv"], 4],
            ["\\C-POL\\ Dairy Cattle", ["3.B.1.C.d.POL-v"], 4],
            ["\\C-POL\\ Non-dairy Cattle", ["3.B.1.C.d.POL-vi"], 4],
            ["\\C-SVN\\ Non-dairy cattle", ["3.B.1.B.d.SVN-i"], 4],
            ["\\C-SVN\\ Other cows", ["3.B.1.B.d.SVN-ii"], 4],
            ["\\C-CHL\\ Dairy Cattle", ["3.B.1.B.d.CHL-i"], 4],
            ["\\C-CHL\\ Beef cattle", ["3.B.1.B.d.CHL-ii"], 4],
            ["\\C-CHL\\ Heifer", ["3.B.1.B.d.CHL-iii"], 4],
            ["\\C-CHL\\ Beef cattle (> 2 yr)", ["3.B.1.B.d.CHL-iv"], 4],
            ["\\C-CHL\\ Beef cattle (1 - 2 yr)", ["3.B.1.B.d.CHL-v"], 4],
            ["\\C-CHL\\ Calves", ["3.B.1.B.d.CHL-vi"], 4],
            [
                "\\C-COL\\ 3.B.1.a.i. High production dairy cattle",
                ["3.B.1.B.d.COL-i"],
                4,
            ],
            [
                "\\C-COL\\ 3.B.1.a.ii. Low production dairy cattle.",
                ["3.B.1.B.d.COL-ii"],
                4,
            ],
            ["\\C-COL\\ 3.B.1.a.iii. Beef cattle", ["3.B.1.B.d.COL-iii"], 4],
            ["\\C-COL\\ 3.B.1.a.iv. Breeding bulls.", ["3.B.1.B.d.COL-iv"], 4],
            ["\\C-COL\\ 3.B.1.a.v. Pre-weaning calves", ["3.B.1.B.d.COL-v"], 4],
            ["\\C-COL\\ 3.B.1.a.vi. Replacement heifers.", ["3.B.1.B.d.COL-vi"], 4],
            [
                "\\C-COL\\ 3.B.1.a.vii. Beef cattle o Feedlot cattle",
                ["3.B.1.B.d.COL-vii"],
                4,
            ],
            # error in panama tables. Young calves present twice, others shifted
            # ["\\C-PAN\\ High production dairy cows", ["3.B.1.B.d.PAN-i"], 4],
            # ["\\C-PAN\\ Low-yielding dairy cows", ["3.B.1.B.d.PAN-i"], 4],
            # ["\\C-PAN\\ Dairy cattle (doble próposito)", ["3.B.1.B.d.PAN-ii"], 4],
            # ["\\C-PAN\\ Young male bull (Novillos)", ["3.B.1.B.d.PAN-iii"], 4],
            # ["\\C-PAN\\ Young calves (terneros)", ["3.B.1.B.d.PAN-iv"], 4],
            # ["\\C-PAN\\ Bull", ["3.B.1.B.d.PAN-v"], 4],
            ["\\C-PAN\\ High production dairy cows", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Low-yielding dairy cows", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Dairy cattle (doble próposito)", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Young male bull (Novillos)", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Young calves (terneros)", ["\\IGNORE"], 4],
            ["\\C-PAN\\ Bull", ["\\IGNORE"], 4],
            ["\\C-USA\\ Dairy cattle", ["3.B.1.B.d.USA-i"], 4],
            ["\\C-USA\\ Non-dairy cattle", ["3.B.1.B.d.USA-ii"], 4],
            ["\\C-USA\\ Dairy cows", ["3.B.1.B.d.USA-iii"], 4],
            ["\\C-USA\\ Heifer feedlot", ["3.B.1.B.d.USA-iv"], 4],
            ["\\C-USA\\ Steer feedlot", ["3.B.1.B.d.USA-v"], 4],
            ["\\C-USA\\ Beef replacements", ["3.B.1.B.d.USA-vi"], 4],
            ["\\C-USA\\ Dairy replacements", ["3.B.1.B.d.USA-vii"], 4],
            ["\\C-USA\\ Beef cows", ["3.B.1.B.d.USA-viii"], 4],
            ["\\C-USA\\ Heifer stocker", ["3.B.1.B.d.USA-ix"], 4],
            ["\\C-USA\\ Steer stocker", ["3.B.1.B.d.USA-x"], 4],
            ["\\C-USA\\ Bulls", ["3.B.1.B.d.USA-xi"], 4],
            ["\\C-USA\\ Dairy calves", ["3.B.1.B.d.USA-xii"], 4],
            ["\\C-USA\\ Beef calves", ["3.B.1.B.d.USA-xiii"], 4],
            ["3.B.2. Sheep", ["3.B.2"], 0],
            ["3.B.2.a. Other (please specify)", ["3.B.2.a"], 1],
            ["\\C-AUS-ITA\\ Sheep", ["\\IGNORE"], 2],
            ["\\C-ARG\\ All sheep", ["\\IGNORE"], 2],
            ["\\C-GHA-CHN\\ sheep", ["\\IGNORE"], 2],
            [
                "\\C-CHL-COL-PAN-SRB-AUT-BLR-CHE-CZE-DNK-ESP-EST-FIN-GRC-HRV-JPN-KAZ-"
                "LIE-LTU-LVA-NLD-NOR-NZL-PRT-SVN-SWE-UKR\\ Sheep",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-BEL\\ Sheep unspecified", ["\\IGNORE"], 2],
            ["\\C-CAN\\ Sheep and Lamb", ["\\IGNORE"], 2],
            ["\\C-BRA\\ 3.B.2. Sheep", ["\\IGNORE"], 2],
            ["\\C-COL\\ 3.B.2.a.i. Sheep", ["\\IGNORE"], 2],
            ["\\C-ITA-NLD\\ Sheep (3)", ["\\IGNORE"], 2],
            ["\\C-NLD\\ Sheep (8)", ["\\IGNORE"], 2],
            [
                "\\C-AZE-BTN-BRN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-URY-"
                "UZB-FRA\\ All sheep [IPCC Software 3.A.2.c]",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 2],
            ["\\C-MLT\\ Growing Lambs", ["3.B.2.a.MLT-i"], 2],
            ["\\C-MLT\\ Other Mature Ewes", ["3.B.2.a.MLT-ii"], 2],
            ["\\C-MLT\\ Mature Ewes", ["3.B.2.a.MLT-iii"], 2],
            ["\\C-SVK\\ Mature ewes", ["3.B.2.a.SVK-i"], 2],
            ["\\C-SVK\\ Growing lambs", ["3.B.2.a.SVK-ii"], 2],
            ["\\C-SVK\\ Other mature sheeps", ["3.B.2.a.SVK-iii"], 2],
            ["\\C-TUR\\ Domestic sheep", ["3.B.2.a.TUR-i"], 2],
            ["\\C-TUR\\ Merino sheep", ["3.B.2.a.TUR-ii"], 2],
            ["\\C-DZA\\ dairy Sheep", ["3.B.2.a.DZA-i"], 2],
            ["\\C-DZA\\ Other Sheep", ["3.B.2.a.DZA-ii"], 2],
            ["\\C-IRL\\ Ewes Lowland", ["3.B.2.a.IRL-i"], 2],
            ["\\C-IRL\\ Ewes Upland", ["3.B.2.a.IRL-ii"], 2],
            ["\\C-IRL\\ Lambs Lowland", ["3.B.2.a.IRL-iii"], 2],
            ["\\C-IRL\\ Lambs Upland", ["3.B.2.a.IRL-iv"], 2],
            ["\\C-IRL\\ Other Sheep>1yr Lowland", ["3.B.2.a.IRL-v"], 2],
            ["\\C-IRL\\ Other Sheep>1yr Upland", ["3.B.2.a.IRL-vi"], 2],
            ["\\C-IRL\\ Rams Lowland", ["3.B.2.a.IRL-vii"], 2],
            ["\\C-IRL\\ Rams Upland", ["3.B.2.a.IRL-viii"], 2],
            ["\\C-ISL\\ Mature ewes", ["3.B.2.a.ISL-i"], 2],
            ["\\C-ISL\\ Animal for replacement", ["3.B.2.a.ISL-ii"], 2],
            ["\\C-ISL\\ Other mature sheep", ["3.B.2.a.ISL-iii"], 2],
            ["\\C-ISL\\ Lambs", ["3.B.2.a.ISL-iv"], 2],
            ["\\C-USA\\ Sheep", ["3.B.2.a.USA-i"], 2],
            ["\\C-USA\\ Sheep on feed", ["3.B.2.a.USA-ii"], 2],
            ["\\C-USA\\ Sheep not on feed", ["3.B.2.a.USA-iii"], 2],
            ["3.B.3. Swine", ["3.B.3"], 0],
            ["3.B.3.a. Other (please specify)", ["3.B.3.a"], 1],
            ["\\C-AUS-ITA-CAN\\ Swine", ["\\IGNORE"], 2],
            ["\\C-NZL\\ Pigs", ["\\IGNORE"], 2],
            ["\\C-ARG\\ All swine", ["\\IGNORE"], 2],
            [
                "\\C-GHA-PAN-SRB-AUT-BLR-CHE-CZE-EST-FIN-GRC-JPN-KAZ-LIE-LTU-LVA-NLD-"
                "NOR-PRT-SVN-SWE-TUR-UKR-CHN\\ Swine",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-BEL\\ Swine unspecified", ["\\IGNORE"], 2],
            ["\\C-ITA-NLD\\ Swine (2)", ["\\IGNORE"], 2],
            ["\\C-BRA\\ 3.B.3. Swine", ["\\IGNORE"], 2],
            ["\\C-NLD\\ Swine (7)", ["\\IGNORE"], 2],
            [
                "\\C-AZE-BTN-BRN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MDV-MUS-MAR-NAM-NGA-URY-"
                "UZB-FRA\\ All swine [IPCC Software 3.A.2.h]",
                ["\\IGNORE"],
                2,
            ],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 2],
            ["\\C-ESP\\ White swine (finishing/fattening pigs)", ["3.B.3.a.ESP-i"], 2],
            ["\\C-ESP\\ White swine (sows)", ["3.B.3.a.ESP-ii"], 2],
            [
                "\\C-ESP\\ Iberian swine (finishing/fattening pigs)",
                ["3.B.3.a.ESP-iii"],
                2,
            ],
            ["\\C-ESP\\ Iberian swine (sows)", ["3.B.3.a.ESP-iv"], 2],
            ["\\C-MLT\\ Breeding boars", ["3.B.3.a.MLT-i"], 2],
            ["\\C-MLT\\ Breeding females - gilts", ["3.B.3.a.MLT-ii"], 2],
            ["\\C-MLT\\ Breeding female - sows", ["3.B.3.a.MLT-iii"], 2],
            ["\\C-MLT\\ Fattening pigs more than 50kg", ["3.B.3.a.MLT-iv"], 2],
            ["\\C-MLT\\ Young pigs 20-50kg", ["3.B.3.a.MLT-v"], 2],
            ["\\C-MLT\\ Piglets less than 20kg", ["3.B.3.a.MLT-vi"], 2],
            ["\\C-SVK-HRV\\ Breeding swine", ["3.B.3.a.SVK-i"], 2],
            ["\\C-SVK-HRV\\ Market swine", ["3.B.3.a.SVK-ii"], 2],
            ["\\C-CHL\\ Pigs", ["3.B.3.a.CHL-i"], 2],
            ["\\C-CHL\\ Boars", ["3.B.3.a.CHL-ii"], 2],
            ["\\C-CHL\\ Juvenile pigs", ["3.B.3.a.CHL-iii"], 2],
            ["\\C-COL\\ 3.B.3.a.i. swine < 6 months", ["3.B.3.a.COL-i"], 2],
            ["\\C-COL\\ 3.B.3.a.ii. Swine > 6 months", ["3.B.3.a.COL-ii"], 2],
            ["\\C-COL\\ 3.B.3.a.iii. Low productivity swine", ["3.B.3.a.COL-iii"], 2],
            ["\\C-DNK\\ Sows", ["3.B.3.a.DNK-i"], 2],
            ["\\C-DNK\\ Fattening pigs", ["3.B.3.a.DNK-ii"], 2],
            ["\\C-DNK\\ Weaners", ["3.B.3.a.DNK-iii"], 2],
            ["\\C-IRL\\ Boars", ["3.B.3.a.IRL-i"], 2],
            ["\\C-IRL\\ Sows in Pig", ["3.B.3.a.IRL-ii"], 2],
            ["\\C-IRL\\ Gilts in Pig", ["3.B.3.a.IRL-iii"], 2],
            ["\\C-IRL\\ Pigs > 20kg", ["3.B.3.a.IRL-iv"], 2],
            ["\\C-IRL\\ Pigs < 20kg", ["3.B.3.a.IRL-v"], 2],
            ["\\C-IRL\\ Other Sows for Breeding", ["3.B.3.a.IRL-vi"], 2],
            ["\\C-IRL\\ Gilts not yet Served", ["3.B.3.a.IRL-vii"], 2],
            ["\\C-ISL\\ Piglets", ["3.B.3.a.ISL-i"], 2],
            ["\\C-ISL\\ Sows", ["3.B.3.a.ISL-ii"], 2],
            ["\\C-USA\\ Swine", ["3.B.3.a.USA-i"], 2],
            ["\\C-USA\\ Market swine less than 50 lb", ["3.B.3.a.USA-ii"], 2],
            ["\\C-USA\\ Market swine 50-119 lb", ["3.B.3.a.USA-iii"], 2],
            ["\\C-USA\\ Market swine 120-179 lb", ["3.B.3.a.USA-iv"], 2],
            ["\\C-USA\\ Market swine greater than 180 lb", ["3.B.3.a.USA-v"], 2],
            ["\\C-USA\\ Breeding swine", ["3.B.3.a.USA-vi"], 2],
            # other livestock
            # ["\\C!-AUS-CHL\\ 3.B.4. Other livestock(4)", ["3.B.4"], 0],
            # ["\\C-AUS-ARG-AZE-\\ 3.B.4. Other livestock (4)", ["3.B.4"], 0],
            # ["\\C-CHL\\ 3.B.4. Other livestock (please specify) (4)", ["3.B.4"], 0],
            ["3.B.4. Other livestock (6)", ["3.B.4"], 0],
            ["\\C-AUS-CHL\\ Drop-down list", ["\\IGNORE"], 1],
            ["\\C-SGP\\ NA", ["\\IGNORE"], 1],
            ["3.B.4.a. Buffalo", ["3.B.4.a"], 1],
            ["3.B.4.b. Camels", ["3.B.4.b"], 1],
            ["3.B.4.c. Deer", ["3.B.4.c"], 1],
            ["3.B.4.d. Goats", ["3.B.4.d"], 1],
            ["3.B.4.e. Horses", ["3.B.4.e"], 1],
            ["3.B.4.f. Mules and asses", ["3.B.4.f"], 1],
            ["3.B.4.g. Poultry", ["3.B.4.g"], 1],
            ["\\C!-CHL\\ 3.B.4.h. Other", ["3.B.4.h"], 1],
            ["\\C-CHL\\ 3.B.4.h. Other (please specify)", ["3.B.4.h"], 1],
            ["\\C-AUS\\ Drop-down list:", ["\\IGNORE"], 2],
            ["3.B.4.h.i. Rabbit", ["3.B.4.h.i"], 2],
            ["3.B.4.h.ii. Reindeer", ["3.B.4.h.ii"], 2],
            ["3.B.4.h.iii. Ostrich", ["3.B.4.h.iii"], 2],
            ["3.B.4.h.iv Fur-bearing animals (7)", ["3.B.4.h.iv"], 2],
            ["\\C!-CHL\\ 3.B.4.h.v. Other (please specify)", ["3.B.4.h.v"], 2],
            ["\\C-CHL\\ 3.B.4.h.v. Other (please specity)", ["3.B.4.h.v"], 2],
            ["\\C-AUS\\ Alpacas", ["3.B.4.h.v.1"], 3],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " Alpacas [IPCC Software 3.A.2.j]",
                ["3.B.4.h.v.1"],
                3,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " Llamas [IPCC Software 3.A.2.j]",
                ["3.B.4.h.v.2"],
                3,
            ],
            [
                "\\C-GUY-AZE-BTN-EGY-GNB-GUY-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-URY-UZB\\"
                " All other species [IPCC Software 3.A.2.j]",
                ["3.B.4.h.v.10"],
                3,
            ],
            ["\\C-SGP\\ Quail", ["3.B.4.h.v.3"], 3],
            ["\\C-ESP\\ Ducks and other poultry", ["3.B.4.h.v.4"], 3],
            ["\\C-ESP\\ Turkeys", ["3.B.4.h.v.5"], 3],
            ["\\C-ESP\\ Broilers", ["3.B.4.h.v.6"], 3],
            ["\\C-CHE\\ Livestock outside agriculture", ["3.B.4.h.v.11"], 3],
            ["\\C-COL\\ 3.B.4.g.i. Laying hens", ["3.B.4.h.v.12"], 3],
            ["\\C-COL\\ 3.B.4.g.ii. broiler chicken", ["3.B.4.h.v.13"], 3],
            ["\\C-CAN\\ Wild Boar", ["3.B.4.h.v.14"], 3],
            ["\\C-CHL\\ Wild boars", ["3.B.4.h.v.14"], 3],
            ["\\C-DNK\\ Pheasants", ["3.B.4.h.v.15"], 3],
            ["\\C-LTU\\ Nutria", ["3.B.4.h.v.16"], 3],
            ["\\C-USA\\ American bison", ["3.B.4.h.v.17"], 3],
            ["\\C-CHL\\ Llamas, alpacas, huarizos", ["3.B.4.h.v.18"], 3],
        ],
        "entity_mapping": {
            "EMISSIONS N2O Direct Nitrogen leaching and run-off": "N2O",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    # TODO: tables 3.A and 3.B for livestock details as they are not contained in table3
    "Table3.C": {  # rice cultivation details
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 25,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Harvested area (2)",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Organic amendments added (3)",
                "IMPLIED EMISSION FACTOR (1) CH4",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) The IEF implicitly takes account of all relevant corrections for "
                "continuously flooded fields without organic amendments, the correction"
                " for organic amendments and the effect of different soil "
                "characteristics, if considered in the calculation of CH4 emissions.",
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["3.C.1. Irrigated", ["3.C.1"]],
            ["3.C.1.a. Continuously flooded", ["3.C.1.a"]],
            ["3.C.1.b. Intermittently flooded", ["3.C.1.b"]],
            ["3.C.1.b.i. Single aeration", ["3.C.1.b.i"]],
            ["3.C.1.b.ii.Multiple aeration", ["3.C.1.b.ii"]],
            ["3.C.2. Rain-fed", ["3.C.2"]],
            ["3.C.2.a. Flood-prone", ["3.C.2.a"]],
            ["3.C.2.b. Drought-prone", ["3.C.2.b"]],
            ["3.C.3. Deep water", ["3.C.3"]],
            ["3.C.3.a. Water depth 50–100 cm", ["3.C.3.a"]],  # noqa: RUF001
            ["3.C.3.b. Water depth > 100 cm", ["3.C.3.b"]],
            ["3.C.4. Other (please specify)", ["3.C.4"]],
            ["\\C-AUS-BRA-CHL-SGP\\ NA", ["\\IGNORE"]],
            ["\\C-COL\\ 3.C.4. Other", ["3.C.4.a"]],
            ["\\C-EST\\ Other non-specified", ["3.C.4.a"]],
            ["\\C-LTU\\ Other", ["3.C.4.a"]],
            ["\\C-GHA\\ Upland", ["3.C.4.b"]],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-"
                "URY-UZB-FRA\\ Other rice ecosystems [IPCC Software 3.C.7]",
                ["3.C.4.a"],
            ],
            ["\\C-CHN\\ 3.C.4.a. Water-logged in fallow season", ["3.C.4.c"]],
            # ignore as just for comparison
            ["Upland rice(4)", ["\\IGNORE"]],
            ["Total(4)", ["\\IGNORE"]],
        ],
        "entity_mapping": {
            "EMISSIONS CH4": "CH4",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table3.D": {  # direct and indirect N2O from soils
        "status": "tested",
        "table": {
            "firstrow": 7,
            "lastrow": 24,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Description",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Value",
                "IMPLIED EMISSION FACTORS Value",
                # "Fraction (a) FracGASF",
                # "Description Fraction of synthetic fertilizer N applied to soils that "
                # "volatilises as NH3 and NOX",
                # "Value 0.11",
            ],
            "stop_cats": [
                "",
                "nan",
                "(1) To convert from N2O–N to N2O emissions, multiply by 44/28.",  # noqa: RUF001
            ],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["3.D.1. Direct N2O emissions from managed soils", ["3.D.a"]],
            ["3.D.1.a. Inorganic N fertilizers (3)", ["3.D.a.1"]],
            ["3.D.1.b. Organic N fertilizers (3)", ["3.D.a.2"]],
            ["3.D.1.b.i. Animal manure applied to soils", ["3.D.a.2.a"]],
            ["3.D.1.b.ii. Sewage sludge applied to soils", ["3.D.a.2.b"]],
            ["3.D.1.b.iii. Other organic fertilizers applied to soils", ["3.D.a.2.c"]],
            ["3.D.1.c. Urine and dung deposited by grazing animals", ["3.D.a.3"]],
            ["3.D.1.d. Crop residues", ["3.D.a.4"]],
            [
                "3.D.1.e. Mineralization/immobilization associated with loss/gain of "
                "soil organic matter (4,5)",
                ["3.D.a.5"],
            ],
            ["3.D.1.f. Cultivation of organic soils (i.e. histosols) (2)", ["3.D.a.6"]],
            ["3.D.1.g. Other", ["3.D.a.7"]],
            ["3.D.2. Indirect N2O Emissions from managed soils", ["3.D.b"]],
            ["3.D.2.a. Atmospheric deposition (6)", ["3.D.b.1"]],
            ["3.D.2.b. Nitrogen leaching and run-off", ["3.D.b.2"]],
        ],
        "entity_mapping": {
            "EMISSIONS N2O": "N2O",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    "Table3.E": {  # savanna burning details
        "status": "TODO",  # actually done but empty and crashes
        "table": {
            "firstrow": 7,
            "lastrow": 13,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Area of savannah burned",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Average above-ground biomass density",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Biomass burned",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Fraction of savannah "
                "burned",
                "ACTIVITY DATA AND OTHER RELATED INFORMATION Nitrogen fraction in biomass",
                "IMPLIED EMISSION FACTORS CH4",
                "IMPLIED EMISSION FACTORS N2O",
            ],
            "stop_cats": ["", ".", "nan"],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [
            ["3.E.1. Forest land (specify ecological zone) (2)", ["3.E.1"], 0],
            ["NA", ["\\IGNORE"], 1],
            ["3.E.2. Grassland (specify ecological zone) (2)", ["3.E.2"], 0],
            ["NA", ["\\IGNORE"], 1],
        ],
        "entity_mapping": {
            "EMISSIONS (2) CH4": "CH4",
            "EMISSIONS (2) N2O": "N2O",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # TODO
    "Table3.F": {  # field burning details
        "status": "TODO",
        "table": {
            "firstrow": 7,
            "lastrow": 29,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": ["", "nan"],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [],
        "entity_mapping": [],
        "coords_defaults": {
            "class": "Total",
        },
    },  # TODO
    "Table3.G-I": {  # liming, urea, carbon containing fertilizer
        "status": "TODO",
        "table": {
            "firstrow": 5,
            "lastrow": 13,
            "header": ["group", "entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": ["", "nan"],
            "unit_info": unit_info["default"],
        },
        "sector_mapping": [],
        "entity_mapping": [],
        "coords_defaults": {
            "class": "Total",
        },
    },  # TODO
    "Table4": {  # LULUCF overview
        "status": "tested",
        "table": {
            "firstrow": 8,
            "lastrow": 33,
            "header": ["entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": ["", ".", "nan"],
            "unit_info": unit_info["industry"],
        },
        "sector_mapping": [
            ["4. Total LULUCF", ["4"]],
            ["4.A. Forest land", ["4.A"]],
            ["4.A.1. Forest land remaining forest land", ["4.A.1"]],
            ["4.A.2. Land converted to forest land", ["4.A.2"]],
            ["4.B. Cropland", ["4.B"]],
            ["4.B.1. Cropland remaining cropland", ["4.B.1"]],
            ["4.B.2. Land converted to cropland", ["4.B.2"]],
            ["4.C. Grassland", ["4.C"]],
            ["4.C.1. Grassland remaining grassland", ["4.C.1"]],
            ["4.C.2. Land converted to grassland", ["4.C.2"]],
            ["4.D. Wetlands (5)", ["4.D"]],
            ["4.D.1. Wetlands remaining wetlands", ["4.D.1"]],
            ["4.D.2. Land converted to wetlands", ["4.D.2"]],
            ["4.E. Settlements", ["4.E"]],
            ["4.E.1. Settlements remaining settlements", ["4.E.1"]],
            ["4.E.2. Land converted to settlements", ["4.E.2"]],
            ["4.F. Other land (6)", ["4.F"]],
            ["4.F.1. Other land remaining other land", ["4.F.1"]],
            ["4.F.2. Land converted to other land", ["4.F.2"]],
            ["4.G. Harvested wood products (7)", ["4.G"]],
            ["4.H. Other (please specify)", ["4.H"]],
            # coomented to find out where they come from
            # ["Land converted to Settlement", ["4.H.1"]],
            ["\\C-FRA\\ Biogenic NMVOCs from managed forest", ["4.H.4"]],
            ["\\C-FRA\\ Reservoir of Petit-Saut in French Guiana", ["4.H.5"]],
            ["\\C-AUS-ECU\\ Aquaculture", ["4.H.10"]],
            ["\\C-AUS-ECU\\ Seagrass", ["4.H.11"]],
            [
                "\\C-GUY-MDV-AZE-BTN-BRN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-"
                "URY-UZB\\ N2O emissions from aquaculture [IPCC Software 3.C.12]",
                ["4.H.6"],
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-URY-"
                "UZB-\\ Other emissions from LULUCF [IPCC Software 3.D.2]",
                ["4.H.9"],
            ],
            ["\\C-SGP-NZL-LTU\\ Other", ["4.H.9"]],
            ["\\C-COL-HRV\\ 4.H. Other", ["4.H.9"]],
            ["\\C-BRA\\ Total", ["4.H.9"]],
            ["\\C-JPN\\ Concrete using Biochar", ["4.H.10"]],
            ["\\C-CHN\\ Trees outside forests", ["4.H.11"]],
            ["\\C-CHL\\ NA", ["\\IGNORE"]],
            # currently ignoring memo item
        ],
        "entity_mapping": {
            "CH4(2)": "CH4",
            "N2O(2)": "N2O",
            "Net CO2 emissions/removals (1,2)": "CO2",
            "Total GHG emissions/removals (3)": f"KYOTOGHG ({gwp_to_use})",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    # TODO: all other LULUCF tables
    "Table5": {  # Waste overview
        "status": "tested",
        "table": {
            "firstrow": 8,
            "lastrow": 31,
            "header": ["entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": [
                "",
                "nan",
                '(1) "Total GHG emissions" does not include NOX, CO, NMVOC and SOX.',
            ],
            "unit_info": unit_info["industry"],
        },
        "sector_mapping": [
            ["5. Total waste", ["5"]],
            ["5.A. Solid waste disposal", ["5.A"]],
            ["5.A.1. Managed waste disposal sites", ["5.A.1"]],
            ["5.A.2. Unmanaged waste disposal sites", ["5.A.2"]],
            ["5.A.3. Uncategorized waste disposal sites", ["5.A.3"]],
            ["5.B. Biological treatment of solid waste", ["5.B"]],
            ["5.B.1. Composting", ["5.B.1"]],
            ["5.B.2. Anaerobic digestion at biogas facilities", ["5.B.2"]],
            ["5.C. Incineration and open burning of waste", ["5.C"]],
            ["5.C.1. Waste incineration", ["5.C.1"]],
            ["5.C.2. Open burning of waste", ["5.C.2"]],
            ["5.D. Wastewater treatment and discharge", ["5.D"]],
            ["5.D.1. Domestic wastewater", ["5.D.1"]],
            ["5.D.2. Industrial wastewater", ["5.D.2"]],
            ["5.D.3. Other", ["5.D.3"]],
            ["5.E. Other (please specify)", ["5.E"]],
            ["Accidential fires at Solid Waste Disposal Sites", ["5.E.9"]],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB\\ CH₄ and N₂O emissions from methane flaring at waste facilities "
                "[IPCC Software 4.E]",
                ["5.E.6"],
            ],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PAN-PRY-"
                "URY-UZB-FRA\\ "
                "Other waste emissions [IPCC Software 4.E, SO₂ from 4.A-4.D]",
                ["5.E.5"],
            ],
            ["\\C-CZE\\ Other waste", ["5.E.5"]],
            ["\\C-FIN-LTU\\ Other", ["5.E.5"]],
            ["\\C-COL\\ 5.E. Other", ["5.E.5"]],
            ["\\C-SGP-BRA-CHL\\ NA", ["\\IGNORE"]],
            ["\\C-ECU\\ NO", ["\\IGNORE"]],
            ["\\C-CHE\\ Car shredding", ["5.E.10"]],
            ["\\C-DNK\\ Accidental fires", ["5.E.3"]],
            ["\\C-ESP\\ Accidental combustion", ["5.E.3"]],
            ["\\C-ESP\\ Sludge spreading", ["5.E.7"]],
            ["\\C-JPN\\ Decomposition of fossil-fuel derived surfactants", ["5.E.4"]],
            ["\\C-PRT\\ Biogas burning without energy recovery", ["5.E.6"]],
            ["\\C-CAN\\ Fossil CO2 from Industrial wastewater", ["5.E.8"]],
            ["Memo item: (3)", ["\\IGNORE"]],
            ["5.F.1. Long-term storage of C in waste disposal sites", ["M.Memo.LTSW"]],
            [
                "\\C!-CHL-ECU\\ 5.F.2. Annual change in total long-term C storage",
                ["M.Memo.ACLT"],
            ],
            [
                "\\C-CHL-ECU\\ 5.F.1.a. Annual change in total long-term C storage",
                ["M.Memo.ACLT"],
            ],
            [
                "\\C!-CHL-ECU\\ "
                "5.F.3. Annual change in total long-term C storage in HWP waste (4)",
                ["M.Memo.ACLTHWP"],
            ],
            [
                "\\C-CHL-ECU\\ "
                "5.F.1.b. Annual change in total long-term C storage in HWP waste (4)",
                ["M.Memo.ACLTHWP"],
            ],
        ],
        "entity_mapping": {
            # "CO2(1)": "CO2",
            "Total GHG emissions (1)": f"KYOTOGHG ({gwp_to_use})",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
    # TODO 5.A-D
    "Summary1": {  # Summary 1
        "status": "tested",
        "table": {
            "firstrow": 8,
            "lastrow": 74,
            "header": ["entity", "unit"],
            "col_for_categories": "GREENHOUSE GAS SOURCE AND SINK CATEGORIES",
            "categories": ["category"],
            "cols_to_ignore": [],
            "stop_cats": [
                "(1) The emissions of HFCs, PFCs, unspecified mix of HFCs and PFCs and "
                "other F-gases are to be expressed as CO2 eq. emissions. Data on "
                "disaggregated emissions of HFCs and PFCs are to be provided in "
                "table 2(II) of this common reporting format."
            ],
            "unit_info": unit_info["summary"],
        },
        "sector_mapping": [
            ["Total national emissions and removals", ["0"]],
            ["1. Energy", ["1"]],
            ["1.A. Fuel combustion", ["1.A"]],
            ["1.A.1. Energy industries", ["1.A.1"]],
            ["1.A.2. Manufacturing industries and construction", ["1.A.2"]],
            ["1.A.3. Transport", ["1.A.3"]],
            ["1.A.4. Other sectors", ["1.A.4"]],
            ["1.A.5. Other", ["1.A.5"]],
            ["1.B. Fugitive emissions from fuels", ["1.B"]],
            ["1.B.1. Solid fuels", ["1.B.1"]],
            [
                "1.B.2. Oil and natural gas and other emissions from energy production",
                ["1.B.2"],
            ],
            ["1.C. CO2 Transport and storage", ["1.C"]],
            ["2. Industrial processes and product use", ["2"]],
            ["2.A. Mineral industry", ["2.A"]],
            ["2.B. Chemical industry", ["2.B"]],
            ["2.C. Metal industry", ["2.C"]],
            ["2.D. Non-energy products from fuels and solvent use", ["2.D"]],
            ["2.E. Electronic industry", ["2.E"]],
            ["2.F. Product uses as substitutes for ODS", ["2.F"]],
            ["2.G. Other product manufacture and use", ["2.G"]],
            ["2.H. Other (4)", ["2.H"]],
            ["3. Agriculture", ["3"]],
            ["3.A. Enteric fermentation", ["3.A"]],
            ["3.B. Manure management", ["3.B"]],
            ["3.C. Rice cultivation", ["3.C"]],
            ["3.D. Agricultural soils", ["3.D"]],
            ["3.E. Prescribed burning of savannahs", ["3.E"]],
            ["3.F. Field burning of agricultural residues", ["3.F"]],
            ["3.G. Liming", ["3.G"]],
            ["3.H. Urea application", ["3.H"]],
            ["3.I. Other carbon-containing fertilizers", ["3.I"]],
            ["3.J. Other", ["3.J"]],
            ["4. Land use, land-use change and forestry (5)", ["4"]],
            ["4.A. Forest land (5)", ["4.A"]],
            ["4.B. Cropland (5)", ["4.B"]],
            ["4.C. Grassland (5)", ["4.C"]],
            ["4.D. Wetlands (5)", ["4.D"]],
            ["4.E. Settlements (5)", ["4.E"]],
            ["4.F. Other land (5)", ["4.F"]],
            ["4.G. Harvested wood products (5)", ["4.G"]],
            ["4.H. Other (5)", ["4.H"]],
            ["5. Waste", ["5"]],
            ["5.A. Solid waste disposal (6)", ["5.A"]],
            ["5.B. Biological treatment of solid waste", ["5.B"]],
            ["5.C. Incineration and open burning of waste (6)", ["5.C"]],
            ["5.D. Wastewater treatment and discharge", ["5.D"]],
            ["5.E. Other (6)", ["5.E"]],
            ["6. Other (please specify) (7)", ["6"]],
            [
                "\\C-GUY-MDV-AZE-BTN-EGY-GNB-IDN-KEN-LBN-MYS-MUS-MAR-NAM-NGA-PRY-URY-UZB\\"
                " Other sources of emissions/removals [IPCC Software 5.C]",
                ["6.A"],
            ],
            ["\\C-CHE\\ Other non-specified", ["6.A"]],
            ["\\C-JPN\\ Smoking", ["6.B"]],
            ["\\C-NZL\\ 6. Tokelau_1. Energy", ["6.NZL-A"]],
            [
                "\\C-NZL\\ 6. Tokelau_2. Industrial Processes and Product Use",
                ["6.NZL-B"],
            ],
            ["\\C-NZL\\ 6. Tokelau_3. Agriculture", ["6.NZL-C"]],
            ["\\C-NZL\\ 6. Tokelau_5. Waste", ["6.NZL-D"]],
            ["\\C-AUS-BRA-CHL-ECU-SGP\\ NA", ["\\IGNORE"]],
            ["\\C-COL-LTU\\ Other", ["6.A"]],
            ["\\C-GHA\\ Aquaculture", ["6.B"]],
            ["", ["\\IGNORE"]],
            ["nan", ["\\IGNORE"]],
            ["Memo items: (8)", ["\\IGNORE"]],
            ["1.D.1. International bunkers", ["M.Memo.Int"]],
            ["1.D.1.a. Aviation", ["M.Memo.Int.Avi"]],
            ["1.D.1.b. Navigation", ["M.Memo.Int.Mar"]],
            ["1.D.2. Multilateral operations", ["M.Memo.Mult"]],
            ["1.D.3. CO2 emissions from biomass", ["M.Memo.Bio"]],
            ["1.D.4. CO2 captured", ["M.Memo.CO2Cap"]],
            ["5.F.1. Long-term storage of C in waste disposal sites", ["M.Memo.LTSW"]],
            ["Indirect N2O", ["M.Memo.IndN2O"]],
            ["Indirect CO2", ["M.Memo.IndCO2"]],
        ],
        "entity_mapping": {
            "NOX": "NOx",
            "Net CO2 emissions/ removals": "CO2",
            "HFCs (1)": f"HFCS ({gwp_to_use})",
            "PFCs (1)": f"PFCS ({gwp_to_use})",
            "Unspecified mix of HFCs and PFCs (1)": f"UnspMixOfHFCsPFCs ({gwp_to_use})",
            "Total GHG emissions/removals (2)": f"KYOTOGHG ({gwp_to_use})",
        },
        "coords_defaults": {
            "class": "Total",
        },
    },  # tested
}

for table in tables_identical:
    CRT1_PRY[table] = CRT1[table]
